@@ -1,7 +1,7 @@
 /***************************************************************************
  * aspline.c -- aspline does an Akima spline interpolation.                *
  *                                                                         *
- * spline is (c) David Frey, 1996, 1998, 1999, 2002                        *
+ * spline is (c) David Frey, 1996, 1998, 1999, 2002, 2009                  *
  *                                                                         *
  * This program is free software; you can redistribute it and/or modify it *
  * under the terms of the GNU General Public License as published by the   *
@@ -325,7 +325,7 @@ void readandcalcspline(FILE *infile, const char *inname,
     char *il;
 
     if (line != NULL) free(line);
-    line=getline(infile); il=line; l++;
+    line=local_getline(infile); il=line; l++;
     if (il != NULL)
       while (isspace(*il)) il++;
 
