@@ -46,15 +46,15 @@ void *xrealloc(void *ptr, size_t size)
   return ptr;
 }
 
-unsigned char *getline(FILE *stream)
+char *local_getline(FILE *stream)
 /* Read a line of text without imposing an length limit */
 /* From: Bison Manual */
 {
-  unsigned char *line;
+  char *line;
   int c;
   int i;
 
-  line=(unsigned char *)xmalloc(LINEFRAGMENT+1); i=0;
+  line=xmalloc(LINEFRAGMENT+1); i=0;
   while (((c=fgetc(stream)) != EOF) && (c != '\n')) {
     if ((i > LINEFRAGMENT) && (i % LINEFRAGMENT) == 0)
       line=(unsigned char *)xrealloc(line,i+LINEFRAGMENT+1);
